cd "C:\Shazam\AER"
log using "vc-out-med-BM 2006-19 2output 10Oct2020", replace
* AER VC CD & TLG LSE & SFA models, common time trend
* Australia & NZ data runs 2006-2019, Ontario data runs 2005-2018
* for NZ include Vector and Wellington separately for full period
* for Ontario include 4 Alectra component DNSPs for 2005-2016 and Alectra from 2017 on
* 2 output model with customer numbers and circuit length
* Australian DNSP identifiers are 1 ACT, 2 AGD, 3 CIT, 4 END, 5 ENX
* 6 ERG, 7 ESS, 8 JEN, 9 PCR, 10 SAP, 11 AND, 12 TND, 13 UED
version 11
clear
set more off
set maxiter 200
import excel "DNSPData AusNZOnt 8Oct2020x BM.xls", sheet("DNSP Med") firstrow
summarize
correlate CustNum CircLen RMDemand

generate DNSP=0
replace DNSP=int(EIID/100) if Country==1
replace DNSP=EIID-2000+13 if Country==2
replace DNSP=EIID-3000+32 if Country==3

xtset DNSP Year

* adjust to calendar year
generate yr=Year
replace yr=yr+0.5 if DNSP==3
replace yr=yr+0.5 if DNSP==8
replace yr=yr+0.5 if DNSP==9
replace yr=yr+0.5 if DNSP==11
replace yr=yr+0.5 if DNSP==13
replace yr=yr-0.25 if Country==2
replace yr=yr+0.5 if Country==3

* adjust base to 2012
replace PrOpex=PrOpex/1.239047935 if Country==1
replace PrOpex=PrOpex/1.221665248 if Country==2
replace PrOpex=PrOpex/1.160126855 if Country==3

* adjust for PPPs in 2012
* Australia PPP = 1.527404363
* NZ PPP = 1.482877481
* Canada PPP = 1.249076963
* converting into Australian Dollar base
replace PrOpex=PrOpex*1.482877481/1.527404363 if Country==2
replace PrOpex=PrOpex*1.249076963/1.527404363 if Country==3

generate vc=Opex/PrOpex
generate lvc=log(vc)

generate uc2=vc/CustNum
generate uc3=vc/CircLen
generate obs=DNSP*10+Year-2004
*scatter uc2 obs, saving(uc2)
*scatter uc3 obs, saving(uc3)

generate ly2=log(CustNum)
generate ly3=log(CircLen)

generate z1=ShareUGC

generate lz1=log(z1)

* mean correct output data
qui reg ly2
predict mly2
replace ly2=ly2-mly2
qui reg ly3
predict mly3
replace ly3=ly3-mly3

generate cd2=0
replace cd2=1 if Country==2
generate cd3=0
replace cd3=1 if Country==3

generate ly1=0
generate ly22=ly2*ly2/2
generate ly33=ly3*ly3/2
generate ly23=ly2*ly3

* construct dummy variables
qui tabulate DNSP, gen(d)

* models with 2 outputs:

regress lvc ly2-ly3 lz1 yr cd2 cd3
regress lvc ly2-ly3 ly22 ly23 ly33 lz1 yr cd2 cd3

regress lvc ly2-ly3 lz1 yr cd2 cd3 d2-d13
regress lvc ly2-ly3 ly22 ly23 ly33 lz1 yr cd2 cd3 d2-d13

xtpcse lvc ly2-ly3 lz1 yr cd2 cd3 d2-d13, c(a) het
xtpcse lvc ly2-ly3 ly22 ly23 ly33 lz1 yr cd2 cd3 d2-d13, c(a) het

set matsize 1000
mkmat ly1
mkmat ly2
mkmat ly3
generate c=1
mkmat c
matrix bh3=e(b)
matlist bh3
matrix e1=c*0
matrix e2=c*bh3[1,1]+ly1*0+ly2*bh3[1,3]+ly3*bh3[1,4]
matrix e3=c*bh3[1,2]+ly1*0+ly2*bh3[1,4]+ly3*bh3[1,5]
matrix elas = e1, e2, e3
matrix list elas

qui reg lvc ly2-ly3 lz1 yr cd2 cd3
matrix b0 = e(b), .1, ln(e(rmse)^2) , .1
xtfrontier lvc ly2-ly3 lz1 yr cd2 cd3, ti cost from(b0, copy)
predict ci,te
frontier_teci ci
generate ceff=1/ci
generate ceff_l=1/ci_u
generate ceff_u=1/ci_l
list DNSP Year ceff ceff_l ceff_u
summarize DNSP Year ceff ceff_l ceff_u

generate ceffcd=ceff

drop ci ci_u ci_l ceff ceff_l ceff_u

qui reg lvc ly2-ly3 ly22 ly23 ly33 lz1 yr cd2 cd3
matrix b0 = e(b), .1, ln(e(rmse)^2) , .1
xtfrontier lvc ly2-ly3 ly22 ly23 ly33 lz1 yr cd2 cd3, ti cost from(b0, copy)
predict ci,te
frontier_teci ci
generate ceff=1/ci
generate ceff_l=1/ci_u
generate ceff_u=1/ci_l
list DNSP Year ceff ceff_l ceff_u
summarize DNSP Year ceff ceff_l ceff_u

generate cefftl=ceff

drop ci ci_u ci_l ceff ceff_l ceff_u

list DNSP Year ceffcd cefftl
summarize DNSP Year cefftl ceffcd

matrix bh3=e(b)
matlist bh3
matrix e1=c*0
matrix e2=c*bh3[1,1]+ly1*0+ly2*bh3[1,3]+ly3*bh3[1,4]
matrix e3=c*bh3[1,2]+ly1*0+ly2*bh3[1,4]+ly3*bh3[1,5]
matrix elas = e1, e2, e3
matrix list elas

log close
